@@ -4,7 +4,7 @@ require Exporter;
 require DynaLoader;
 use vars qw(@ISA $VERSION);
 @ISA = qw(Exporter DynaLoader);
-$VERSION = 0.06;
+$VERSION = 0.07;
 bootstrap Image::Filter $VERSION;
 
 sub filter
@@ -44,6 +44,8 @@ None by default.
 
 =head1 FILTERS
 
+=over 4
+
 =item Blur
 
 Basic, none to fancy, blur routine (truecolor)
@@ -90,6 +92,10 @@ Basic, none to fancy, invert routine (truecolor)
 
 Basic, none to fancy, level routine. Add a certain value to every RGB value (truecolor)
 
+=item Oilify
+
+Oilify algorithm. Quite processor intensive. (truecolor
+
 =item Pixelize
 
 Basic, none to fancy, pixelize routine (truecolor)
@@ -110,6 +116,10 @@ Basic, none to fancy, Counter Clockwise Rotation routine (truecolor)
 
 Basic, none to fancy, sharpen routine (truecolor)
 
+=item Solarize
+
+Solarize an image (truecolor)
+
 =item Swirl
 
 Funny rotation routine (truecolor)
@@ -118,8 +128,12 @@ Funny rotation routine (truecolor)
 
 Funny rotation routine (truecolor)
 
+=back
+
 =head1 METHODS
 
+=over 4
+
 =item newFromJpeg($filename)
 
 Load data from a JPEG file. Returns an Image::Filter instance
@@ -162,6 +176,8 @@ Dump image data to gd2 file. Existing file will be overwritten (if possible).
 
 Destroy the instance of Image::Filter. (RECOMMENDED USE)
 
+=back
+
 =head1 CALL FOR PARTICIPATION
 
 Obviously, I'm no expert in math or C. If you feel like writing some filter code or have a nice algorithm you want to see implemented, give me a shout.
